==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'На рассмотрении',
	'articles_meme_auteur' => 'Все статьи этого автора',
	'articles_off' => 'Удалено',
	'articles_publie' => 'Опубликованные',
	'articles_refuse' => 'Удалено',
	'articles_tous' => 'Все',
	'aucun_article_syndic' => 'Нет ни одной импортированной статьи',
	'avis_echec_syndication_01' => 'Не удалось импортировать статьи: не удается прочитать файл-источник или он не содержит ни одной статьи.',
	'avis_echec_syndication_02' => 'Не удалось импортировать статьи: не найден файл-источник (RSS) этого сайта.',
	'avis_site_introuvable' => 'Не удалось найти сайт',
	'avis_site_syndique_probleme' => 'Внимание: не удалось импортировать материалы. В результате работа модуля импорта была прервана. Проверьте ссылку на файл-источник  (<b> @url_syndic@ </b>), и попробуйте еще раз.',
	'avis_sites_probleme_syndication' => 'На этом сайте возникли проблемы с экспортом материалов',
	'avis_sites_syndiques_probleme' => 'Попытка импортировать материалы с этого сайта вызвала ошибку',

	// B
	'bouton_exporter' => 'Экспорт',
	'bouton_importer' => 'Импорт',
	'bouton_radio_modere_posteriori' => 'сразу публиковать',
	'bouton_radio_modere_priori' => 'не публиковать до подтверждения',
	'bouton_radio_non_syndication' => 'Не импортировать статьи на сайт',
	'bouton_radio_syndication' => 'Импортировать материалы',

	// C
	'confirmer_purger_syndication' => 'Вы уверенны, что хотите удалить все импортированные статьи с этого сайта ?',

	// E
	'entree_adresse_fichier_syndication' => 'RSS лента(ы):',
	'entree_adresse_site' => '<b>URL сайта</b> [обязательно]',
	'entree_description_site' => 'Описание сайта',
	'erreur_fichier_format_inconnu' => 'Формат файла @fichier@ не поддерживается системой.',
	'erreur_fichier_incorrect' => 'Невозможно прочитать файл.',

	// F
	'form_prop_nom_site' => 'Название сайта',

	// I
	'icone_article_syndic' => 'Импортированная статья',
	'icone_articles_syndic' => 'Импортированные статьи',
	'icone_controler_syndication' => 'Импортированные статьи',
	'icone_modifier_site' => 'Редактировать сайт',
	'icone_referencer_nouveau_site' => 'Добавить сайт',
	'icone_site_reference' => 'Каталог веб сайтов',
	'icone_supprimer_article' => 'Удалить статью',
	'icone_supprimer_articles' => 'Удалить статьи',
	'icone_valider_article' => 'Утвердить статью',
	'icone_valider_articles' => 'Утвердить статьи',
	'icone_voir_sites_references' => 'Каталог сайтов',
	'info_1_site_importe' => '1 сайт был импортирован',
	'info_a_valider' => '[проверяется]',
	'info_aucun_site_importe' => 'Не был импортирован ни один сайт',
	'info_bloquer' => 'блок',
	'info_bloquer_lien' => 'удалить',
	'info_derniere_syndication' => 'Дата последнего импорта материалов ',
	'info_liens_syndiques_1' => 'импортированных статей',
	'info_liens_syndiques_2' => 'ожидают утверждения.',
	'info_nb_sites_importes' => 'Было импортировано @nb@ сайтов',
	'info_nom_site_2' => '<b>Название сайта</b> [обязательно]',
	'info_panne_site_syndique' => 'Сайт недоступен',
	'info_probleme_grave' => 'ошибка',
	'info_question_proposer_site' => 'Кому разрешено предлагать ссылки на другие сайты?',
	'info_retablir_lien' => 'восстановить',
	'info_site_attente' => 'Cайт, ожидающий проверки',
	'info_site_propose' => 'Добавлен для проверки:',
	'info_site_reference' => 'Ссылки на онлайн сайты',
	'info_site_refuse' => 'Сайт отклонен',
	'info_site_syndique' => 'Можно импортировать статьи с этого сайта',
	'info_site_valider' => 'Ожидающие утверждения',
	'info_sites_referencer' => 'Добавить сайт',
	'info_sites_refuses' => 'Удаленные сайты',
	'info_statut_site_1' => 'Этот сайт:',
	'info_statut_site_2' => 'Опубликовано',
	'info_statut_site_3' => 'Предложено',
	'info_statut_site_4' => 'Удалено',
	'info_syndication' => 'RSS:',
	'info_syndication_articles' => 'статья(и)',
	'item_bloquer_liens_syndiques' => 'Все сайты требуют проверки перед добавлением',
	'item_gerer_annuaire_site_web' => 'Включить каталог сайтов и импорт статей по RSS',
	'item_non_bloquer_liens_syndiques' => 'По умолчанию разрешать добавлять материалы',
	'item_non_gerer_annuaire_site_web' => 'Отключить  каталог сайтов и импорт статей по RSS',
	'item_non_utiliser_syndication' => 'Выключить функцию импорта статей по RSS',
	'item_utiliser_syndication' => 'Включить функцию импорта статей по RSS',

	// L
	'label_exporter_avec_mots_cles_1' => 'Экспортировать ключевые слова как теги',
	'label_exporter_id_parent' => 'Экспортировать сайт из раздела',
	'label_exporter_publie_seulement_1' => 'Экспортировать только опубликованные сайты',
	'label_fichier_import' => 'HTML файл',
	'label_importer_les_tags_1' => 'Импортировать теги как ключевые слова',
	'label_importer_statut_publie_1' => 'Публиковать сайты автоматически',
	'lien_mise_a_jour_syndication' => 'Обновить сейчас',
	'lien_nouvelle_recuperation' => 'Попробовать получить информацию снова',
	'lien_purger_syndication' => 'Удалить все импортированные статьи',

	// N
	'nombre_articles_syndic' => '@nb@ статей импортировано',

	// S
	'statut_off' => 'Удалено',
	'statut_prop' => 'Ожидают',
	'statut_publie' => 'Опубликовано',
	'syndic_choix_moderation' => 'Как поступать с новыми материалами?',
	'syndic_choix_oublier' => 'Как поступать с материалами, которые убрали из RSS ленты сайта-источника?',
	'syndic_choix_resume' => 'Часть сайтов экспортируют в RSS ленту полный текст материала. Что импортировать в таком случае:',
	'syndic_lien_obsolete' => 'устаревшая ссылка',
	'syndic_option_miroir' => 'отправлять на проверку',
	'syndic_option_oubli' => 'удалить их (через @mois@ мес.)',
	'syndic_option_resume_non' => 'материал полностью (HTML формат)',
	'syndic_option_resume_oui' => 'краткое содержание (тестовый формат)',
	'syndic_options' => 'Настройки импорта:',

	// T
	'texte_expliquer_export_bookmarks' => 'Вы можете экспортировать список сайтов в HTML формате закладок, что бы в дальнейшем добавить их в свой броузер или онлайн сервис управления закладками.',
	'texte_expliquer_import_bookmarks' => 'Вы можете добавить список сайтов в формате закладок из вашего броузера или онлайн сервиса по хранению закладок.',
	'texte_liens_sites_syndiques' => 'Вы можете модерировать все материалы, импортированные с других сайтов. Эта настройка устанавливает правило по умолчанию для вновь добавленных сайтов. В любом случае вы можете задавать правила отдельно для каждого сайта.',
	'texte_messages_publics' => 'Комментарии к статье:',
	'texte_non_fonction_referencement' => 'Вы можете задать название сайта и его описание самостоятельно.',
	'texte_referencement_automatique' => '<b>Укажите адрес сайта. </b> <br /> SPIP автоматически определит название сайта и информацию о нем.',
	'texte_referencement_automatique_verifier' => 'Информация о сайте <tt>@url@</tt> была импортирована автоматически. Проверьте её перед добавлением сайта.',
	'texte_syndication' => 'Если на другом сайте есть экспорт материалов через RSS, вы можете автоматически импортировать последние статьи на ваш сайт. Для этого необходимо активировать импорт статей на вашем сайте. 
  <blockquote> <i> Необходимо отметить, что на части сайтов нет автоматического экспорта материалов через RSS ленту. В таком случае вы не сможете получать информацию с таких сайтов в автоматическом режиме. </i> </blockquote>',
	'titre_articles_syndiques' => 'Статьи, импортированные с этого сайта',
	'titre_dernier_article_syndique' => 'Последние импортированные статьи',
	'titre_exporter_bookmarks' => 'Экспортировать Закладки',
	'titre_importer_bookmarks' => 'Импортировать Закладки',
	'titre_importer_exporter_bookmarks' => 'Импортировать и экспортировать закладки',
	'titre_page_sites_tous' => 'Каталог сайтов',
	'titre_referencement_sites' => 'Каталог сайтов, импорт статей по RSS',
	'titre_site_numero' => 'НОМЕР САЙТА:',
	'titre_sites_proposes' => 'Предложенные сайты',
	'titre_sites_references_rubrique' => 'Ссылки на сайты в текущем разделе',
	'titre_sites_syndiques' => 'Сайты-источники информации',
	'titre_sites_tous' => 'Каталог сайтов',
	'titre_syndication' => 'Импорт статей с другого сайта по RSS',
	'tout_voir' => 'Показать все импортированные статьи',

	// U
	'un_article_syndic' => '1 импортированная статья'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'На рассмотрении',
	'articles_meme_auteur' => 'Все статьи этого автора',
	'articles_off' => 'Удалено',
	'articles_publie' => 'Опубликовано',
	'articles_refuse' => 'Удалено',
	'articles_tous' => 'Все',
	'aucun_article_syndic' => 'Нет ни одной импортированной статьи',
	'avis_echec_syndication_01' => 'Не удалось импортировать статьи: не удается прочитать файл-источник или он не содержит ни одной статьи.',
	'avis_echec_syndication_02' => 'Не удалось импортировать статьи: не найден файл-источник (RSS) этого сайта.',
	'avis_site_introuvable' => 'Не удалось найти сайт',
	'avis_site_syndique_probleme' => 'Внимание: не удалось импортировать материалы. В результате работа модуля импорта была прервана. Проверьте ссылку на файл-источник  (<b> @url_syndic@ </b>), и попробуйте еще раз.',
	'avis_sites_probleme_syndication' => 'На этом сайте возникли проблемы с экспортом материалов',
	'avis_sites_syndiques_probleme' => 'Попытка импортировать материалы с этого сайта вызвала ошибку',

	// B
	'bouton_exporter' => 'Экспорт',
	'bouton_importer' => 'Импорт',
	'bouton_radio_modere_posteriori' => 'сразу публиковать',
	'bouton_radio_modere_priori' => 'не публиковать до подтверждения',
	'bouton_radio_non_syndication' => 'Не импортировать статьи на сайт',
	'bouton_radio_syndication' => 'Импортировать материалы',

	// C
	'confirmer_purger_syndication' => 'Вы уверенны, что хотите удалить все импортированные статьи с этого сайта ?',

	// E
	'entree_adresse_fichier_syndication' => 'RSS лента(ы):',
	'entree_adresse_site' => '<b>URL сайта</b> [обязательно]',
	'entree_description_site' => 'Описание сайта',
	'erreur_fichier_format_inconnu' => 'Формат файла @fichier@ не поддерживается системой.',
	'erreur_fichier_incorrect' => 'Невозможно прочитать файл.',

	// F
	'form_prop_nom_site' => 'Название сайта',

	// I
	'icone_article_syndic' => 'Импортированная статья',
	'icone_articles_syndic' => 'Импортированные статьи',
	'icone_controler_syndication' => 'Импортированные статьи',
	'icone_modifier_site' => 'Редактировать сайт',
	'icone_referencer_nouveau_site' => 'Добавить сайт',
	'icone_site_reference' => 'Каталог веб сайтов',
	'icone_supprimer_article' => 'Удалить статью',
	'icone_supprimer_articles' => 'Удалить статьи',
	'icone_valider_article' => 'Утвердить статью',
	'icone_valider_articles' => 'Утвердить статьи',
	'icone_voir_sites_references' => 'Каталог сайтов',
	'info_1_article_syndique' => '1 загруженная статья',
	'info_1_site' => '1 сайт',
	'info_1_site_importe' => '1 сайт был импортирован',
	'info_a_valider' => '[проверяется]',
	'info_aucun_article_syndique' => 'Нет загруженных статей',
	'info_aucun_site' => 'Нет сайтов',
	'info_aucun_site_importe' => 'Не был импортирован ни один сайт',
	'info_bloquer' => 'блокировать',
	'info_bloquer_lien' => 'блокировать эту ссылку',
	'info_derniere_syndication' => 'Дата последнего импорта материалов ',
	'info_liens_syndiques_1' => 'ссылки (синдикация)',
	'info_liens_syndiques_2' => 'ожидают утверждения.',
	'info_nb_articles_syndiques' => '@nb@ RSS статей',
	'info_nb_sites' => '@nb@ сайтов',
	'info_nb_sites_importes' => 'Было импортировано @nb@ сайтов',
	'info_nom_site_2' => '<b>Название сайта</b> [обязательно]',
	'info_panne_site_syndique' => 'Сайт недоступен',
	'info_probleme_grave' => 'ошибка',
	'info_question_proposer_site' => 'Кому разрешено предлагать ссылки на другие сайты?',
	'info_retablir_lien' => 'восстановить',
	'info_site_attente' => 'Cайт, ожидающий проверки',
	'info_site_propose' => 'Добавлен для проверки:',
	'info_site_reference' => 'Ссылки на онлайн сайты',
	'info_site_refuse' => 'Сайт отклонен',
	'info_site_syndique' => 'Можно импортировать статьи с этого сайта',
	'info_site_valider' => 'Ожидающие утверждения',
	'info_sites_referencer' => 'Добавить сайт',
	'info_sites_refuses' => 'Удаленные сайты',
	'info_statut_site_1' => 'Этот сайт:',
	'info_statut_site_2' => 'Опубликовано',
	'info_statut_site_3' => 'Предложено',
	'info_statut_site_4' => 'Удалено',
	'info_syndication' => 'RSS:',
	'info_syndication_articles' => 'статья(и)',
	'item_bloquer_liens_syndiques' => 'Блокировать ссылки синдицированных сайтов до утверждения',
	'item_gerer_annuaire_site_web' => 'Включить каталог сайтов и импорт статей по RSS',
	'item_non_bloquer_liens_syndiques' => 'Не блокировать ссылки с синдицированных сайтов',
	'item_non_gerer_annuaire_site_web' => 'Отключить  каталог сайтов и импорт статей по RSS',
	'item_non_utiliser_syndication' => 'Выключить функцию импорта статей по RSS',
	'item_utiliser_syndication' => 'Включить функцию импорта статей по RSS',

	// L
	'label_exporter_avec_mots_cles_1' => 'Экспортировать ключевые слова как теги',
	'label_exporter_id_parent' => 'Экспортировать сайт из раздела',
	'label_exporter_publie_seulement_1' => 'Экспортировать только опубликованные сайты',
	'label_fichier_import' => 'HTML файл',
	'label_importer_les_tags_1' => 'Импортировать теги как ключевые слова',
	'label_importer_statut_publie_1' => 'Публиковать сайты автоматически',
	'lien_mise_a_jour_syndication' => 'Обновить сейчас',
	'lien_nouvelle_recuperation' => 'Попробовать получить информацию снова',
	'lien_purger_syndication' => 'Удалить все импортированные статьи',

	// N
	'nombre_articles_syndic' => '@nb@ статей импортировано',

	// S
	'statut_off' => 'Удалено',
	'statut_prop' => 'Ожидают',
	'statut_publie' => 'Опубликовано',
	'syndic_choix_moderation' => 'Как поступать с новыми материалами?',
	'syndic_choix_oublier' => 'Как поступать с материалами, которые убрали из RSS ленты сайта-источника?',
	'syndic_choix_resume' => 'Часть сайтов экспортируют в RSS ленту полный текст материала. Что импортировать в таком случае:',
	'syndic_lien_obsolete' => 'устаревшая ссылка',
	'syndic_option_miroir' => 'отправлять на проверку',
	'syndic_option_oubli' => 'удалить их (через @mois@ мес.)',
	'syndic_option_resume_non' => 'материал полностью (HTML формат)',
	'syndic_option_resume_oui' => 'краткое содержание (тестовый формат)',
	'syndic_options' => 'Настройки импорта:',

	// T
	'texte_expliquer_export_bookmarks' => 'Вы можете экспортировать список сайтов в HTML формате закладок, что бы в дальнейшем добавить их в свой броузер или онлайн сервис управления закладками.',
	'texte_expliquer_import_bookmarks' => 'Вы можете добавить список сайтов в формате закладок из вашего броузера или онлайн сервиса по хранению закладок.',
	'texte_liens_sites_syndiques' => 'Вы можете модерировать все материалы, импортированные с других сайтов. Эта настройка устанавливает правило по умолчанию для вновь добавленных сайтов. В любом случае вы можете задавать правила отдельно для каждого сайта.',
	'texte_messages_publics' => 'Комментарии к статье:',
	'texte_non_fonction_referencement' => 'Вы можете задать название сайта и его описание самостоятельно.',
	'texte_referencement_automatique' => '<b>Автоматическое реферирование сайта.</b> <br /> Вы можете сослаться на веб-сайт, указав ниже его URL или адрес его файла синдикации. SPIP автоматически определит информацию о сайте (название, описание и т.д.).',
	'texte_referencement_automatique_verifier' => 'Информация о сайте <tt>@url@</tt> была импортирована автоматически. Проверьте её перед добавлением сайта.',
	'texte_syndication' => 'Если на другом сайте есть экспорт материалов через RSS, вы можете автоматически импортировать последние статьи на ваш сайт. Для этого необходимо активировать импорт статей на вашем сайте. 
  <blockquote> <i> Необходимо отметить, что на части сайтов нет автоматического экспорта материалов через RSS ленту. В таком случае вы не сможете получать информацию с таких сайтов в автоматическом режиме. </i> </blockquote>',
	'titre_articles_syndiques' => 'Статьи, импортированные с этого сайта',
	'titre_dernier_article_syndique' => 'Последние импортированные статьи',
	'titre_exporter_bookmarks' => 'Экспортировать Закладки',
	'titre_importer_bookmarks' => 'Импортировать Закладки',
	'titre_importer_exporter_bookmarks' => 'Импортировать и экспортировать закладки',
	'titre_page_sites_tous' => 'Каталог сайтов',
	'titre_referencement_sites' => 'Каталог сайтов, импорт статей по RSS',
	'titre_site_numero' => 'НОМЕР САЙТА:',
	'titre_sites_proposes' => 'Предложенные сайты',
	'titre_sites_references_rubrique' => 'Ссылки на сайты в текущем разделе',
	'titre_sites_syndiques' => 'Сайты-источники информации',
	'titre_sites_tous' => 'Каталог сайтов',
	'titre_syndication' => 'Импорт статей с другого сайта по RSS',
	'tout_voir' => 'Показать все импортированные статьи',

	// U
	'un_article_syndic' => '1 импортированная статья'
);

?>
